PRO L1C_INPMDS, LUNL1B, ISWEEP, MDS_OFFSET, MDS_SIZE, NUM_POINTS_PER_BAND, $
                FIRST_WAVENUM,  LAST_WAVENUM, WNORES, NSPC, MDS_TIME, ALT, $
                ALT_ERR, LAT, LON, RAD_EARTH, BAND_VAL, SPEC 
; VERSION 
;   14MAR05  AD  Fix bug to allow J1,J2 to be calculated if corrupt bands
;   02NOV04  AD  Original. Based on part of Lv2PP.
;
; DESCRIPTION
;   Procedure to input MIPAS L1B MDS data for one sweep
;   Only sets SPEC for bands where BAND_VAL=0
;
; ARGUMENTS
;   INTEGER*4 LUNL1B                 I  LUN for L1B file
;   INTEGER*4 ISWEEP                 I  Sweep# in file
;   INTEGER*4 MDS_OFFSET             I  Offset [bytes] for 1st MDS record
;   INTEGER*4 MDS_SIZE               I  Length [bytes] of MDS records
;   INTEGER*4 NUM_POINTS_PER_BAND(5) I  No. spectral data points per band
;   REAL*8    FIRST_WAVENUM(5)       I  Lower wavenumber boundary of each band
;   REAL*8    LAST_WAVENUM(5)        I  Upper wavenumber boundary of each band
;   REAL*8    WNORES                 I  Wavenumber resolution [cm-1]
;   INTEGER*4 NSPC                   I  No.points in full spectrum from 0
;   INTEGER*4 MDS_TIME(3)            O  Time of sweep [Days,HHMMSS,.tttt]
;   REAL*8    ALT                    O  Tangent altitude [km]
;   REAL*8    ALT_ERR                O  Tangent altitude error [km]
;   REAL*4    LAT                    O  Latitude [deg]
;   REAL*4    LON                    O  Longitude [deg]
;   REAL*8    RAD_EARTH              O  Earth Radius of Curvature [km]
;   INTEGER*1 BAND_VAL(5)            O  Band Validity (0=OK)
;   REAL*4    SPEC(NSPC)             O  Radiance spectrum [nW/(cm2.sr.cm-1)]

; MDS_SIZE for one sweep = 239941 = 1521 + (59605*4) bytes, 59605 grid pts

; Should now be positioned at the start of the required sweep/MDS
; There are 1521 bytes of information before the start of the A band spectrum

MDS_TIME = LONARR(3)          ; 12 bytes days from 1-JAN-2000, hh:mm:ss, .tttt
DUM43 = BYTARR(43)            ; 43 bytes to be skipped
ALT   = 0.0D0                 ;  8 bytes tangent point altitude [km]
ALT_ERR = 0.0D0               ;  8 bytes altitude error [km]
ILAT  = 0L                    ;  4 bytes latitude [deg*1E-6]
ILON  = 0L                    ;  4 bytes longitude [deg*1E-6]
RAD_EARTH = 0.0D0             ;  8 bytes radius of curvature [km]
DUM54 = BYTARR(54)            ; 54 bytes to be skipped
SWEEP_ID = 0                  ;  2 bytes Sweep# within scan
DUM1347 = BYTARR(1347)        ; 1347 bytes to be skipped
BAND_VAL = BYTARR(5)          ;  5 bytes band validity (0=OK)
DUM26 = BYTARR(26)            ; 26 bytes to be skipped
L1BSPEC = FLTARR(TOTAL(NUM_POINTS_PER_BAND))  ; Array for spectra (all 5 bands)

POINT_LUN, LUNL1B, MDS_OFFSET + ( ISWEEP - 1 ) * MDS_SIZE

READU, LUNL1B, MDS_TIME, DUM43, ALT, ALT_ERR, ILAT, ILON, RAD_EARTH,$
  DUM54, SWEEP_ID, DUM1347, BAND_VAL, DUM26, L1BSPEC

LAT = ILAT * 1.0E-6          ; convert from deg*1E-6 to deg
LON = ILON * 1.0E-6

SPEC = FLTARR(NSPC)
J2 = -1
FOR IBAND = 0, 4 DO BEGIN
  J1 = J2 + 1
  J2 = J1 + NUM_POINTS_PER_BAND[IBAND] - 1
  IF BAND_VAL[IBAND] EQ 0 THEN BEGIN
    I1 = ROUND ( FIRST_WAVENUM[IBAND] / WNORES )
    I2 = ROUND ( LAST_WAVENUM[IBAND] / WNORES )
    SPEC[I1:I2] = L1BSPEC[J1:J2] * 1.0E9   ; convert from W/cm2... to nW/cm2...
  ENDIF
ENDFOR

END
