PRO L1C_INPSCAN, LUNL1B, NUM_NESR_PNTS, ADS_OFFSET, ADS_LENGTH, NUM_SWEEPS, $
                 SCAN_TIME, NESR_DATA
;
; VERSION 
;   02NOV04  AD  Original. Based on part of Lv2PP.
;
; DESCRIPTION
; Procedure to extract Scan ADS information from L1B file.
; Since the SCAN Information ADS DSRs are of variable length, we need to
; construct list of starting points for the DSR corresponding to each scan
; The length of each DSR is written in bytes#13-16 of each DSR
;
; ARGUMENTS
;   INTEGER*4 LUNL1B        I  LUN for L1B file
;   INTEGER*4 NUM_NESR_PNTS I  No.of NESR points
;   INTEGER*4 ADS_OFFSET    I  Offset for this Scan ADS
;   INTEGER*4 ADS_LENGTH    O  Length of this record
;   INTEGER*4 NUM_SWEEPS    O  No. sweeps in scan
;   INTEGER*4 SCAN_TIME     O  Time [secs] of 1st sweep in scan
;   REAL*4 NESR_DATA(NUM_NESR_PNTS,NUM_SWEEPS) O NESR data in nW

DSR_TIME = LONARR(3)                   ; time code for 1st sweep in scan
ADS_LENGTH = 0L
DUM19 = BYTARR(19)
NUM_SWEEPS = 0    
DUM161 = BYTARR(161)
NUM_PK_FIT = 0
DUM46 = BYTARR(46)  

POINT_LUN, LUNL1B, ADS_OFFSET        ; Point to start of ADS DSR for ISCAN
READU, LUNL1B, DSR_TIME, ADS_LENGTH, DUM19, NUM_SWEEPS, DUM161, NUM_PK_FIT, $
       DUM46 

SCAN_TIME = DSR_TIME[1]

DUM32 = BYTARR(32)

; The next piece of the L1B record is of variable length which has to be 
; evaluated from NUM_PK_FIT and NUM_COADD_SCENE read from the data
NUM_COADD_SCENE = 0                  ;   2 bytes Number of coadded scene meas.
FOR IPEAK = 1, NUM_PK_FIT DO BEGIN
  READU, LUNL1B, DUM32, NUM_COADD_SCENE
  NSKIP1 = BYTARR(2*NUM_COADD_SCENE)       ; 2*K bytes to be skipped
  READU, LUNL1B, NSKIP1
ENDFOR

NESR_DATA = FLTARR ( NUM_NESR_PNTS, NUM_SWEEPS ) 
READU, LUNL1B, NESR_DATA
NESR_DATA = NESR_DATA * 1.0E9     

END
