PRO L1C_MICNOI, NUM_NESR_PNTS, NESR_FIRST_WAVENUM, NESR_LAST_WAVENUM, $
                NESR_DATA, ISWP, NMIC, OUTMIC, WN1MIC, WN2MIC, NOIMIC
;
; VERSION
;   02NOV04  AD  Original. Derived from mwext.pro
;
; DESCRIPTION
;   Assign NESR value to each microwindow for current sweep.
;
; ARGUMENTS
;   INTEGER*4 NUM_NESR_PNTS          I  No.of NESR points
;   REAL*4    NESR_FIRST_WAVENUM     I  Lower wavenumber for NESR tabulation
;   REAL*4    NESR_LAST_WAVENUM      I  Upper wavenumber for NESR tabulation
;   REAL*4    NESR_DATA(NUM_NESR_PNTS,NUM_SWEEPS) I NESR data in nW
;   INTEGER*2 ISWP                   I  Sweep index within scan
;   INTEGER*2 NMIC                   I  No. of microwindows
;   INTEGER*1 OUTMIC(NMIC)           I  1=output, 0=no output
;   REAL*8    WN1MIC(NMIC)           I  MW Lower wavenumber boundaries
;   REAL*8    WN2MIC(NMIC)           I  MW Upper wavenumber boundaries
;   REAL*4    NOIMIC(NMIC)           O  Average NESR for each MW

IF NMIC EQ 0 THEN RETURN
NOIMIC = FLTARR ( NMIC )

FOR IMIC = 0, NMIC-1 DO BEGIN
  IF OUTMIC[IMIC] THEN BEGIN
    WNO = 0.5 * ( WN1MIC[IMIC] + WN2MIC[IMIC] )
    X = ( WNO - NESR_FIRST_WAVENUM ) / (NESR_LAST_WAVENUM-NESR_FIRST_WAVENUM) $
        * FLOAT ( NUM_NESR_PNTS - 1 )
    X = MEDIAN ( [ 0, X, NUM_NESR_PNTS - 1 ] )  ; limit X to 0:nnp-1
    I = FIX ( X ) 
    J = MIN ( [ I+1, NUM_NESR_PNTS - 1 ] )
    IF NESR_DATA[I,ISWP] NE 0 AND NESR_DATA[J,ISWP] NE 0 THEN BEGIN
      NOIMIC[IMIC] = ( X - FLOAT(I) ) * NESR_DATA[J,ISWP] + $
                     ( FLOAT(J) - X ) * NESR_DATA[I,ISWP]  
    ENDIF ELSE BEGIN
      IF NESR_DATA[I,ISWP] EQ 0 THEN NOIMIC[IMIC] = NESR_DATA[J,ISWP]
      IF NESR_DATA[J,ISWP] EQ 0 THEN NOIMIC[IMIC] = NESR_DATA[I,ISWP]
    ENDELSE
  ENDIF
ENDFOR

END
