PRO L1C_TIME, MDS_TIME, IYEAR, IDAY, ISEC, DATE, TIME
;
; VERSION
;   02NOV04  AD  Changed name (was ymdt.pro) and arguments 
;   15OCT02  AD  Rewrite. Correct DATE to avoid blank space in seconds
;   06JUN02  AD  Convert DATE to use yyyy instead of yy
;   06JUN02  CP  Original
;
; DESCRIPTION
;   Procedure to convert ESA time format to more convenient variables
;   ESA time is a 3-element integer array: Modified Julian Day#(1=01-JAN-2000),
;   seconds into day, and microseconds (?) - last not used.
;
; ARGUMENTS
;   INTEGER*4   MDS_TIME(3) I Time in ESA-format
;   INTEGER*2   IYEAR       O  Year yyyy, eg 2002
;   INTEGER*2   IDAY        O  Day# within year (1:366)
;   INTEGER*4   ISEC        O  Seconds within day (0:86400)
;   CHARACTER*8 DATE        O  Date 'yyyymmdd' format
;   CHARACTER*6 TIME        O  Time 'hhmmss' format

; CALDAT is IDL procedure to convert proper Julian Day to date, month, year
; 2451545 is the proper Julian date corresponding to 01-jan-2000

CALDAT, 2451545L+MDS_TIME[0], MONTH, DAYMON, YEAR
 
DATE = STRING ( YEAR, FORMAT='(I4)' ) + $               ; yyyymmdd
       STRING ( MONTH, FORMAT='(I2.2)' ) + $
       STRING ( DAYMON, FORMAT='(I2.2)' )                

IYEAR = FIX ( YEAR )

; Compute the day of the year

IF YEAR MOD 4 EQ 0 THEN BEGIN                           ; leap years
  MESEG = [31,29,31,30,31,30,31,31,30,31,30,31] 
ENDIF ELSE BEGIN                                           
  MESEG = [31,28,31,30,31,30,31,31,30,31,30,31] 
ENDELSE

IF MONTH EQ 1 THEN BEGIN
  DAY = DAYMON
ENDIF ELSE BEGIN
  DAY = ROUND ( TOTAL ( MESEG[0:MONTH-2] ) ) + DAYMON 
ENDELSE
IDAY = FIX ( DAY )

ISEC = MDS_TIME[1]                              ; Seconds into day

; Compute time in hhmmss (integer division assumed)

TIME = STRING ( ISEC/3600, FORMAT='(I2.2)' ) + $           ; hours      
       STRING ( ISEC/60 MOD 60, FORMAT='(I2.2)' ) + $      ; minutes
       STRING ( ISEC MOD 60, FORMAT='(I2.2)' )             ; seconds
END